@@ -108,30 +108,55 @@ def nano_copysource(mapping, OUTPUT="copied_fastq_reads", exist_ok=False):
     os.makedirs(OUTPUT, exist_ok=exist_ok)
     root_dir = os.path.abspath(OUTPUT)
 
-    fastq_source = pd.read_csv(mapping, sep="\t", names=["Sample", "Read_path"], header=None)
-    print(f"Total reads from source {fastq_source.shape[0]}")
-
-
     # add summary report
     raw_read = defaultdict(list)
-    for row, content in fastq_source.iterrows():
 
-        sam = os.path.join(root_dir, os.path.basename(content["Sample"]))
-        read_from = content["Read_path"]
-        if os.path.exists(read_from):
-            read_to = os.path.join(sam, os.path.basename(read_from))
-            print(f"\n{row} Copying  sample {read_from} to working directory {sam}")
-        else:
-            print("read path does not exist")
-            return "read path does not exist"
+    if type(mapping) == defaultdict:
 
-        if not os.path.exists(sam):
-            os.makedirs(sam)
+        fastq_source = mapping
 
-        raw_read[sam].append(read_to)
-        command = " ".join(["cp", read_from, read_to])
-        subprocess.run(command, shell=True)
-        
+        for k, v in fastq_source.items():
+            for j in v:
+                sam = os.path.join(root_dir, os.path.basename(k))
+                read_from = j
+
+                if os.path.exists(read_from):
+                    read_to = os.path.join(sam, os.path.basename(read_from))
+                    print(f"\nCopying  sample {read_from} to working directory {sam}")
+                else:
+                    print("read path does not exist")
+                    return "read path does not exist"
+
+                if not os.path.exists(sam):
+                    os.makedirs(sam)
+
+                raw_read[sam].append(read_to)
+                command = " ".join(["cp", read_from, read_to])
+                subprocess.run(command, shell=True)
+            
+
+    else:
+        fastq_source = pd.read_csv(mapping, sep="\t", names=["Sample", "Read_path"], header=None)
+        print(f"Total reads from source {fastq_source.shape[0]}")
+
+        for row, content in fastq_source.iterrows():
+
+            sam = os.path.join(root_dir, os.path.basename(content["Sample"]))
+            read_from = content["Read_path"]
+            if os.path.exists(read_from):
+                read_to = os.path.join(sam, os.path.basename(read_from))
+                print(f"\n{row} Copying  sample {read_from} to working directory {sam}")
+            else:
+                print("read path does not exist")
+                return "read path does not exist"
+
+            if not os.path.exists(sam):
+                os.makedirs(sam)
+
+            raw_read[sam].append(read_to)
+            command = " ".join(["cp", read_from, read_to])
+            subprocess.run(command, shell=True)
+            
     print("Completed")
     return raw_read
 
@@ -168,7 +193,7 @@ def nano_concat(sample_read_dict, mergeby="Sample", output="Concat_reads", filet
             # resolve arguments too long eror with cat
             uplevelfrom = os.path.dirname(reads[0]) 
             print(f"//Find files from source: {uplevelfrom}")
-            command = " ".join(["cat", f"{uplevelfrom}/*", ">", outread_path])
+            command = " ".join(["cat", f"{uplevelfrom}/*.{filetype}", ">", outread_path])
             print(command)
             print("\n")
             subprocess.run(command, shell=True)
@@ -176,7 +201,7 @@ def nano_concat(sample_read_dict, mergeby="Sample", output="Concat_reads", filet
     elif mergeby == "All":
         print("Concat all reads...")
         all_reads = [ j for i in sample_read_dict.values() for j in i]
-        all_reads_upper = { os.path.dirname(i)+"/*" for i in all_reads }
+        all_reads_upper = { os.path.dirname(i)+f"/*.{filetype}" for i in all_reads }
         outread = "all_concat_reads"+"."+filetype
         outread_path = os.path.join(out, outread)
         read_mapping[out].append(outread_path)
@@ -190,8 +215,7 @@ def nano_concat(sample_read_dict, mergeby="Sample", output="Concat_reads", filet
     return read_mapping
 
 
-
-def nano_runProg(sample_read_dict, *args, method="qcat", inputflag="-f", outputflag="-o", outfolder=None, outfolder_suffix="out", forceout = False, stdin = False, xlabel="", suffix_change=False, outfmt="", exist_ok=True, switchinput_output=False, catchstdout=False, stdout_fmt=""):
+def nano_runProg(sample_read_dict, *args, method="qcat", inputflag="-f", outputflag="-o",outfolder=None, outfolder_suffix="out", forceout = False, stdin = False, xlabel="", suffix_change=False, outfmt="", exist_ok=True, switchinput_output=False, catchstdout=False, stdout_fmt=""):
     """Demultiplex with qcat or porechop
 
     Args:
